wsic package
============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   wsic.metadata

Submodules
----------

wsic.cli module
---------------

.. automodule:: wsic.cli
   :members:
   :undoc-members:
   :show-inheritance:

wsic.codecs module
------------------

.. automodule:: wsic.codecs
   :members:
   :undoc-members:
   :show-inheritance:

wsic.enums module
-----------------

.. automodule:: wsic.enums
   :members:
   :undoc-members:
   :show-inheritance:

wsic.magic module
-----------------

.. automodule:: wsic.magic
   :members:
   :undoc-members:
   :show-inheritance:

wsic.multiprocessing module
---------------------------

.. automodule:: wsic.multiprocessing
   :members:
   :undoc-members:
   :show-inheritance:

wsic.readers module
-------------------

.. automodule:: wsic.readers
   :members:
   :undoc-members:
   :show-inheritance:

wsic.types module
-----------------

.. automodule:: wsic.types
   :members:
   :undoc-members:
   :show-inheritance:

wsic.utils module
-----------------

.. automodule:: wsic.utils
   :members:
   :undoc-members:
   :show-inheritance:

wsic.writers module
-------------------

.. automodule:: wsic.writers
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: wsic
   :members:
   :undoc-members:
   :show-inheritance:
